@@ -17,7 +17,7 @@ require Exporter;
 
 @ISA       = qw(Exporter);
 @EXPORT_OK = qw(encrypt decrypt encrypt_hex decrypt_hex);
-$VERSION   = '2.05';
+$VERSION   = '2.10';
 
 
 ########################################
@@ -573,8 +573,12 @@ For example DES expects an eight byte key.
   $blocksize = $ecb->blocksize;
 
 These methods can be used to retrieve keysize and blocksize as
-reported from the block cipher chosen. They can be used as well to
-override the values that are reported from the cipher module.
+reported from the block cipher chosen.
+
+They can be used as well to override the values that are reported from
+the cipher module. Of course that doesn't make sense unless the block
+cipher used supports the new values. E.g. Crypt::Rijndael works with
+16, 24 and 32 byte keys.
 
 =head2 padding()
 
@@ -705,7 +709,7 @@ recognize whether these functions are called in an OO context or not.
 
 B<encrypt()> and B<decrypt()> process the provided text and return either
 the corresponding ciphertext (encrypt) or plaintext (decrypt). Data
-and padstyle are optional. If the padding style is ommited, 'standard'
+and padstyle are optional. If the padding style is omitted, 'standard'
 is assumed. If data is omitted, $_ is used.
 
 B<encrypt_hex()> and B<decrypt_hex()> operate on ciphertext in a
@@ -714,7 +718,7 @@ B<encrypt()> and B<decrypt()>.
 
 =head1 BUGS
 
-None that I know of.
+None that I know of. Please report if you find any.
 
 =head1 TODO
 
@@ -725,21 +729,10 @@ could be added.
 
 A taint check on the key like Crypt::CBC does could be added.
 
-=head1 COPYING
+=head1 LICENSE
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+This module is distributed under the "Artistic License" using the same
+terms as Perl itself. 
 
 =head1 AUTHOR
 
